from .matplotlib import setup as mpl_setup

try:
    import altair
    from .vega import setup as vega_setup
    from .vega import RHO_LIGHT as vega_rho_light
    from .vega import RHO_DARK as vega_rho_dark
except ModuleNotFoundError:
    pass

from .sequential_palettes import *



#!/usr/bin/env python3
"""Reads a core set of sequential color scales."""

from importlib.resources import open_text
import json
from matplotlib.colors import LinearSegmentedColormap

SEQUENTIAL = json.load(open_text("rho_plus.data", "sequential_palettes.json"))

for name, colors in SEQUENTIAL.items():
    globals()[name] = colors
